<?php
/**
 * Plugin Name: Darowizny Paybylink.pl
 * Plugin URI: https://paybylink.pl
 * Description: Przyjmowanie darowizn przelewem przez Paybylink.pl
 * Version: 1.0
 * Author: Szymon Radoliński
 */

if(!get_option('pbl_donations_shopid')) {
    update_option('pbl_donations_shopid', ' ');
}

if(!get_option('pbl_donations_hash')) {
    update_option('pbl_donations_hash', ' ');
}

function pbl_register_settings() {
    register_setting( 'pbl_donations_options_group', 'pbl_donations_shopid' );
    register_setting( 'pbl_donations_options_group', 'pbl_donations_hash' );
}
add_action('admin_init', 'pbl_register_settings');

function pbl_register_admin_form() {
    add_options_page('Dotacje Paybylink', 'Dotacje Paybylink.pl', 'manage_options', 'wp-paybylink-donations', 'pbl_admin_form');
}
add_action('admin_menu', 'pbl_register_admin_form');

function pbl_admin_form() {
    $shopid = get_option('pbl_donations_shopid');
    $hash = get_option('pbl_donations_hash');

    echo '<h2>Ustawienia darowizn Paybylink</h2>';
    echo '<form method="post" action="options.php">';
    settings_fields( 'pbl_donations_options_group' );
    echo '<table>';
    echo '<tr><td>Identyfikator sklepu </td><td><input type="text" name="pbl_donations_shopid" id="pbl_donations_shopid" value="' . $shopid . '" placeholder="Identyfikator sklepu"></td></tr>';
    echo '<tr><td>Hash </td><td><input type="text" name="pbl_donations_hash" id="pbl_donations_hash" value="' . $hash . '" placeholder="Hash"></td></tr>';
    echo '</table>';
    submit_button();
    echo '</form>';
}

function pbl_gateway($email = '', $amount = '', $description = 'Darowizna', $returnUrl = '', $control = 'Darowizna') {
    $shopId             = intval(get_option('pbl_donations_shopid'));
    $description        = strval($description);
    $control            = strval($control);
    $email              = strval($email);
    $price              = floatval($amount);
    $returnUrlSuccess   = strval($returnUrl);
    $hash               = get_option('pbl_donations_hash');

    $data   = $hash . "|" . $shopId . "|" . sprintf("%.2f", $price);

    if ($control != null && $control != "") {
        $data .= "|" . $control;
    }

    if ($description != null && $description != "") {
        $data .= "|" . $description;
    }
    
    if ($email != null && $email != "") {
        $data .= "|" . $email;
    }

    if ($returnUrlSuccess != null && $returnUrlSuccess != "") {
        $data .= "|" . $returnUrlSuccess;
    }

    $signature = hash('sha256', $data);

    $paybylinkData  = [
        'shopId'            => $shopId,
        'price'             => $price,
        'control'           => $control,
        'description'       => $description,
        'email'             => $email,
        'returnUrlSuccess'  => $returnUrlSuccess,
        'signature'         => $signature
    ];

    $data_string = json_encode($paybylinkData);

    $ch = curl_init('https://secure.pbl.pl/api/v1/transfer/generate');                                                                      
    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');                                                                    
    curl_setopt($ch, CURLOPT_POSTFIELDS, $data_string);                                                                  
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);                                                                      
    curl_setopt($ch, CURLOPT_HTTPHEADER, array(                                                                          
        'Content-Type: application/json',                                                                                
        'Content-Length: ' . strlen($data_string))                                                                      
    );

    $result = curl_exec($ch);
    $result = json_decode($result);

    if(isset($result->transactionId) AND !empty($result->transactionId)) {
        return 'https://secure.pbl.pl/transfer/' . $result->transactionId;
    }

    return 'Błąd generowania płatności';
}

function pbl_create_link($atts) {
    extract(shortcode_atts(array(
        'email' => '',
        'kwota' => 10.00,
        'opis' => 'Darowizna dla ' . get_site_url(),
        'adres_powrotu' => get_site_url(),
        'opis_kontrolny' => 'Darowizna'
    ), $atts));
  
    return pbl_gateway($email, $kwota, $opis, $adres_powrotu, $opis_kontrolny);
}

function pbl_create_button($atts) {
    extract(shortcode_atts(array(
        'email' => '',
        'kwota' => 10.00,
        'opis' => 'Darowizna dla ' . get_site_url(),
        'adres_powrotu' => get_site_url(),
        'opis_kontrolny' => 'Darowizna',
        'klasy_css' => '',
        'nowa_karta' => 'tak',
        'nazwa_przycisku' => 'Przekaż darowiznę'
    ), $atts));

    $paymentUrl = pbl_gateway($email, $kwota, $opis, $adres_powrotu, $opis_kontrolny);
  
    return '<a href="' . $paymentUrl . '" class="' . str_replace('.', '', $klasy_css) . '"' . ($nowa_karta == 'nie' ? null : ' target="_blank"') . '>' . $nazwa_przycisku . '</a>';
}

add_shortcode('darowizna_pbl_link', 'pbl_create_link');
add_shortcode('darowizna_pbl_przycisk', 'pbl_create_button');